@@ -23,6 +23,7 @@ init_error(void)
     }
 
     PyExc_UVError = PyErr_NewException("pyuv.error.UVError", NULL, NULL);
+    PyExc_ThreadError = PyErr_NewException("pyuv.error.ThreadError", PyExc_UVError, NULL);
     PyExc_HandleError = PyErr_NewException("pyuv.error.HandleError", PyExc_UVError, NULL);
     PyExc_HandleClosedError = PyErr_NewException("pyuv.error.HandleClosedError", PyExc_HandleError, NULL);
     PyExc_AsyncError = PyErr_NewException("pyuv.error.AsyncError", PyExc_HandleError, NULL);
@@ -37,14 +38,13 @@ init_error(void)
     PyExc_TTYError = PyErr_NewException("pyuv.error.TTYError", PyExc_StreamError, NULL);
     PyExc_UDPError = PyErr_NewException("pyuv.error.UDPError", PyExc_HandleError, NULL);
     PyExc_PollError = PyErr_NewException("pyuv.error.PollError", PyExc_HandleError, NULL);
-    PyExc_DNSError = PyErr_NewException("pyuv.error.DNSError", NULL, NULL);
-    PyExc_ThreadPoolError = PyErr_NewException("pyuv.error.ThreadPoolError", PyExc_UVError, NULL);
     PyExc_FSError = PyErr_NewException("pyuv.error.FSError", PyExc_UVError, NULL);
     PyExc_FSEventError = PyErr_NewException("pyuv.error.FSEventError", PyExc_HandleError, NULL);
     PyExc_FSPollError = PyErr_NewException("pyuv.error.FSPollError", PyExc_HandleError, NULL);
     PyExc_ProcessError = PyErr_NewException("pyuv.error.ProcessError", PyExc_HandleError, NULL);
 
     PyUVModule_AddType(module, "UVError", (PyTypeObject *)PyExc_UVError);
+    PyUVModule_AddType(module, "ThreadError", (PyTypeObject *)PyExc_ThreadError);
     PyUVModule_AddType(module, "HandleError", (PyTypeObject *)PyExc_HandleError);
     PyUVModule_AddType(module, "AsyncError", (PyTypeObject *)PyExc_AsyncError);
     PyUVModule_AddType(module, "TimerError", (PyTypeObject *)PyExc_TimerError);
@@ -58,8 +58,6 @@ init_error(void)
     PyUVModule_AddType(module, "TTYError", (PyTypeObject *)PyExc_TTYError);
     PyUVModule_AddType(module, "UDPError", (PyTypeObject *)PyExc_UDPError);
     PyUVModule_AddType(module, "PollError", (PyTypeObject *)PyExc_PollError);
-    PyUVModule_AddType(module, "DNSError", (PyTypeObject *)PyExc_DNSError);
-    PyUVModule_AddType(module, "ThreadPoolError", (PyTypeObject *)PyExc_ThreadPoolError);
     PyUVModule_AddType(module, "FSError", (PyTypeObject *)PyExc_FSError);
     PyUVModule_AddType(module, "FSEventError", (PyTypeObject *)PyExc_FSEventError);
     PyUVModule_AddType(module, "FSPollError", (PyTypeObject *)PyExc_FSPollError);
