@@ -569,8 +569,7 @@ static int
 UDP_tp_traverse(UDP *self, visitproc visit, void *arg)
 {
     Py_VISIT(self->on_read_cb);
-    HandleType.tp_traverse((PyObject *)self, visit, arg);
-    return 0;
+    return HandleType.tp_traverse((PyObject *)self, visit, arg);
 }
 
 
@@ -578,8 +577,7 @@ static int
 UDP_tp_clear(UDP *self)
 {
     Py_CLEAR(self->on_read_cb);
-    HandleType.tp_clear((PyObject *)self);
-    return 0;
+    return HandleType.tp_clear((PyObject *)self);
 }
 
 
