@@ -1,4 +1,6 @@
+# coding=utf8
 
+import socket
 import sys
 
 from common import unittest2
@@ -34,6 +36,15 @@ class TCPErrorTest(unittest2.TestCase):
         client.close()
         loop.run()
 
+    def test_open(self):
+        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        loop = pyuv.Loop.default_loop()
+        client = pyuv.TCP(loop)
+        client.open(sock.fileno())
+        client.connect(("127.0.0.1", TEST_PORT), self.on_client_connect_error)
+        loop.run()
+        sock.close()
+
 
 class TCPTest(unittest2.TestCase):
 
@@ -66,7 +77,7 @@ class TCPTest(unittest2.TestCase):
 
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
-        self.assertEquals(data, b"PING"+common.linesep)
+        self.assertEqual(data, b"PING"+common.linesep)
         client.close()
 
     def test_tcp1(self):
@@ -78,40 +89,67 @@ class TCPTest(unittest2.TestCase):
         self.loop.run()
 
 
+class TCPTest2(unittest2.TestCase):
+
+    def setUp(self):
+        self.loop = pyuv.Loop.default_loop()
+        self.server = None
+        self.client = None
+        self.write_cb_count = 0
+
+    def on_connection(self, server, error):
+        self.assertEqual(error, None)
+        client = pyuv.TCP(pyuv.Loop.default_loop())
+        server.accept(client)
+        for x in range(1024):
+            client.write(b"PING"*1000, self.on_client_write)
+        client.close()
+        server.close()
+
+    def on_client_connection(self, client, error):
+        self.assertEqual(error, None)
+        self.assertTrue(client.readable)
+        self.assertTrue(client.writable)
+
+    def on_client_write(self, handle, error):
+        self.write_cb_count += 1
+
+    def test_tcp_write_cancel(self):
+        self.server = pyuv.TCP(self.loop)
+        self.server.bind(("0.0.0.0", TEST_PORT))
+        self.server.listen(self.on_connection)
+        self.client = pyuv.TCP(self.loop)
+        self.client.connect(("127.0.0.1", TEST_PORT), self.on_client_connection)
+        self.loop.run()
+        self.assertEqual(self.write_cb_count, 1024)
+
+
 class TCPTestUnicode(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
         self.server = None
         self.client = None
-        self.client_connections = []
 
     def on_connection(self, server, error):
         self.assertEqual(error, None)
         client = pyuv.TCP(pyuv.Loop.default_loop())
         server.accept(client)
-        self.client_connections.append(client)
-        client.start_read(self.on_client_connection_read)
         if sys.version_info >= (3, 0):
-            data = 'PING'
+            data = 'PÏNG'
+            exc_type = TypeError
         else:
-            data = unicode('PING')
-        client.write(data)
-
-    def on_client_connection_read(self, client, data, error):
-        if data is None:
-            client.close()
-            self.client_connections.remove(client)
-            self.server.close()
-            return
+            data = unicode('PÏNG', 'utf-8')
+            exc_type = UnicodeEncodeError
+        self.assertRaises(exc_type, client.write, data)
+        client.close()
+        self.server.close()
 
     def on_client_connection(self, client, error):
         self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_client_read(self, client, data, error):
-        self.assertNotEqual(data, None)
-        self.assertEqual(data, b"PING")
         client.close()
 
     def test_tcp_unicode(self):
@@ -194,7 +232,7 @@ class TCPTestNull(unittest2.TestCase):
 
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
-        self.assertEquals(data, b"PIN\x00G"+common.linesep)
+        self.assertEqual(data, b"PIN\x00G"+common.linesep)
         client.close()
 
     def test_tcp_null(self):
@@ -229,12 +267,12 @@ class TCPTestList(unittest2.TestCase):
             return
 
     def on_client_connection(self, client, error):
-        self.assertEquals(error, None)
+        self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
-        self.assertEquals(data, b"PING1PING2PING3PING4PING5PING6PING7PING8PING9PING10PING11PING12")
+        self.assertEqual(data, b"PING1PING2PING3PING4PING5PING6PING7PING8PING9PING10PING11PING12")
         client.close()
 
     def test_tcp_list(self):
@@ -252,32 +290,25 @@ class TCPTestListUnicode(unittest2.TestCase):
         self.loop = pyuv.Loop.default_loop()
         self.server = None
         self.client = None
-        self.client_connections = []
 
     def on_connection(self, server, error):
         client = pyuv.TCP(pyuv.Loop.default_loop())
         server.accept(client)
-        self.client_connections.append(client)
-        client.start_read(self.on_client_connection_read)
         if sys.version_info >= (3, 0):
-            data = 'PING'
+            data = 'PÏNG'
+            exc_type = TypeError
         else:
-            data = unicode('PING')
-        client.writelines([data for x in range(100)])
-
-    def on_client_connection_read(self, client, data, error):
-        if data is None:
-            client.close()
-            self.client_connections.remove(client)
-            self.server.close()
-            return
+            data = unicode('PÏNG', 'utf-8')
+            exc_type = UnicodeEncodeError
+        self.assertRaises(exc_type, client.writelines, [data for x in range(100)])
+        client.close()
+        self.server.close()
 
     def on_client_connection(self, client, error):
-        self.assertEquals(error, None)
+        self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_client_read(self, client, data, error):
-        self.assertEquals(data, b"PING"*100)
         client.close()
 
     def test_tcp_list_unicode(self):
@@ -312,12 +343,12 @@ class TCPTestListNull(unittest2.TestCase):
             return
 
     def on_client_connection(self, client, error):
-        self.assertEquals(error, None)
+        self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
-        self.assertEquals(data, b"PING1PING2PING3PING4PING5PING\x00\xFF6")
+        self.assertEqual(data, b"PING1PING2PING3PING4PING5PING\x00\xFF6")
         client.close()
 
     def test_tcp_list_null(self):
@@ -360,7 +391,7 @@ class TCPTestInvalidData(unittest2.TestCase):
         return
 
     def on_client_connection(self, client, error):
-        self.assertEquals(error, None)
+        self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_client_read(self, client, data, error):
@@ -399,7 +430,7 @@ class TCPShutdownTest(unittest2.TestCase):
             return
 
     def on_client_connection(self, client, error):
-        self.assertEquals(error, None)
+        self.assertEqual(error, None)
         client.start_read(self.on_client_read)
 
     def on_close(self, handle):
@@ -411,7 +442,7 @@ class TCPShutdownTest(unittest2.TestCase):
 
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
-        self.assertEquals(data, b"PING"+common.linesep)
+        self.assertEqual(data, b"PING"+common.linesep)
         client.shutdown(self.on_client_shutdown)
 
     def test_tcp_shutdown(self):
